compute_distance_matrix_gpu: Compute a squared Euclidean distance matrix through the...

View source: R/gpu_backend.R

compute_distance_matrix_gpuR Documentation

Compute a squared Euclidean distance matrix through the optional native backend

Description

Compute a squared Euclidean distance matrix through the optional native backend

Usage

compute_distance_matrix_gpu(X, backend = "auto", device = 0)

Arguments

X

A numeric matrix.

backend

One of "auto", "cpu", or "gpu".

device

Zero-based device id. -1 for native C++.

Value

An n x n squared Euclidean distance matrix.


GreedyExperimentalDesign documentation built on April 30, 2026, 9:07 a.m.