compute_kernel_matrix_gpu: Compute a kernel matrix through the optional native backend

View source: R/gpu_backend.R

compute_kernel_matrix_gpuR Documentation

Compute a kernel matrix through the optional native backend

Description

Compute a kernel matrix through the optional native backend

Usage

compute_kernel_matrix_gpu(X, kernel = "gaussian", ...)

Arguments

X

A numeric matrix.

kernel

One of "gaussian", "laplacian", "inv_mult_quad", "exponential", or "poly".

...

Optional kernel parameters. Supported names are gamma and poly_s.

Value

An n x n kernel matrix.


GreedyExperimentalDesign documentation built on April 30, 2026, 9:07 a.m.