compute_objective_vals_gpu: Compute kernel objective values through the optional native...

View source: R/gpu_backend.R

compute_objective_vals_gpuR Documentation

Compute kernel objective values through the optional native backend

Description

Compute kernel objective values through the optional native backend

Usage

compute_objective_vals_gpu(W, Kgram, device = 0)

Arguments

W

An r x n numeric matrix of design vectors.

Kgram

An n x n kernel Gram matrix.

device

Zero-based device id. -1 for native C++.

Value

A numeric vector with one quadratic form per row of W.


GreedyExperimentalDesign documentation built on April 30, 2026, 9:07 a.m.