resultsMultipleKernelGreedySearch: Returns the results of a greedy multiple kernel search

View source: R/greedy_multiple_kernel_search.R

resultsMultipleKernelGreedySearchR Documentation

Returns the results of a greedy multiple kernel search

Description

Returns the results of a greedy multiple kernel search

Usage

resultsMultipleKernelGreedySearch(obj, max_vectors = NULL, form = "one_zero")

Arguments

obj

The greedy_multiple_kernel_experimental_design object where the search was run.

max_vectors

How many random allocation vectors you wish to return. The default is NULL indicating you want all of them.

form

Which form should it be in? The default is one_zero for 1/0's or pos_one_min_one for +1/-1's.

Author(s)

Adam Kapelner

Examples

 ## Not run: 
	library(MASS)
	data(Boston)
 #pretend the Boston data was an experiment setting 
	#first pull out the covariates
 X = Boston[, 1 : 13]
 #begin the greedy design search
	mk = initGreedyMultipleKernelExperimentalDesignObject(X, 
		max_designs = 100, num_cores = 3, kernel_names = c("mahalanobis", "gaussian"))
	#wait
	res = resultsMultipleKernelGreedySearch(mk, max_vectors = 2, form = "one_zero")
	res$obj_vals
	
## End(Not run)

GreedyExperimentalDesign documentation built on April 30, 2026, 9:07 a.m.