| compute_objective_vals_gpu | R Documentation |
Compute kernel objective values through the optional native backend
compute_objective_vals_gpu(W, Kgram, device = 0)
W |
An |
Kgram |
An |
device |
Zero-based device id. -1 for native C++. |
A numeric vector with one quadratic form per row of W.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.