View source: R/greedy_multiple_kernel_search.R
| resultsMultipleKernelGreedySearch | R Documentation |
Returns the results of a greedy multiple kernel search
resultsMultipleKernelGreedySearch(obj, max_vectors = NULL, form = "one_zero")
obj |
The |
max_vectors |
How many random allocation vectors you wish to return. The default is |
form |
Which form should it be in? The default is |
Adam Kapelner
## Not run:
library(MASS)
data(Boston)
#pretend the Boston data was an experiment setting
#first pull out the covariates
X = Boston[, 1 : 13]
#begin the greedy design search
mk = initGreedyMultipleKernelExperimentalDesignObject(X,
max_designs = 100, num_cores = 3, kernel_names = c("mahalanobis", "gaussian"))
#wait
res = resultsMultipleKernelGreedySearch(mk, max_vectors = 2, form = "one_zero")
res$obj_vals
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.